{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_list %}

{% block title %}{{ title }} | DJ Redis Panel{% endblock %}

{% block extrahead %}
<style type="text/css">
    {% include "admin/dj_redis_panel/styles.css" %}
</style>
{% endblock %}

{% block branding %}
<h1 id="site-name"><a href="{% url 'dj_redis_panel:index' %}">DJ Redis Panel</a></h1>
{% endblock %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; {{ title }}
</div>
{% endblock %}

{% block content %}
{% endblock %}
